#
# spec file for package perl-Data-ShowTable
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Data-ShowTable
Name:           perl-Data-ShowTable
Version:        4.600.0
Release:        1.1
# 4.6 -> normalize -> 4.600.0
%define cpan_version 4.6
#Upstream: SUSE-Public-Domain
License:        GPL-2.0-or-later
Summary:        Perl module to automatically format columnar data
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AK/AKSTE/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Data::ShowTable) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The *ShowTable* module provides subroutines to display tabular data,
typially from a database, in nicely formatted columns, in several formats.
Its arguments can either be given in a fixed order, or, as a single,
anonymous hash-array.

The output format for any one invocation can be one of four possible
styles:

* Box

A tabular format, with the column titles and the entire table surrounded by
a "box" of "'+'", "'-'", and "'|'" characters. See "ShowBoxTable" for
details.

* Table

A simple tabular format, with columns automatically aligned, with column
titles. See "ShowSimpleTable".

* List

A _list_ style, where columns of data are listed as a _name_:_value_ pair,
one pair per line, with rows being one or more column values, separated by
an empty line. See "ShowListTable".

* HTML

The data is output as an HTML _TABLE_, suitable for display through a
_Web_-client. See "ShowHTMLTable". Input can either be plain ASCII text, or
text with embedded HTML elements, depending upon an argument or global
parameter.

The subroutines which perform these displays are listed below.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc bump-version Changes Copyright gen-html gen-tests GNU-LICENSE README showtable testfile testfile.lst testfile.tabs test.pl.off

%changelog
* Thu Feb  6 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Sun Feb  9 2014 coolo@suse.com
- updated to 4.6 - most likely the only perl module without changelog
  (see https://rt.cpan.org/Public/Bug/Display.html?id=92137)
- really remove Data-ShowTable-3.3.dif :)
* Tue Nov 26 2013 coolo@suse.com
- updated to 4.5
  Modified "ShowTable.pm":
  Added "showmode" argument to ShowTableValue so it could handle HTML
  embedded text correctly.  ShowTableValue now uses a string substitution
  "%%s" for any values with embedded HTML tokens, even if defined as an
  integer or real.
  Changed how URLs work: now %%K and %%V are substituted into the URL
  corresponding to the given field name key.  No other insertions are
  done, so the URL is completely specified by the user otherwise.
  Added tableAttrs argument to ShowHTMLTable allowing other stuff to be
  inserted within the TABLE token (ie: <TABLE $table_attrs>).
  Changed the regexp in &PlainText to avoid the multiple null string
  matches.
  Changed htmltext to substitute blanks if the optional second argument
  is non-null (which is used when creating URLs).
  Allow column indexes, as well as column names, to be mapped to URLs.
  Added %%I (column index) key to the url substitutions.
  Removed Sys::OutPut usage.  Added "put" and "out" subs directly.
  Fixed small documentation problems.
  Modified "showtable":
  Added -urls option to support URL mappings for fields.
  Added -attributes option to support table_attributes argument.
- remove obsolete Data-ShowTable-3.3.dif
* Wed Feb  2 2011 vcizek@novell.com
- bzipped source tarball
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Thu Jan 15 2009 anicka@suse.cz
- run tests properly (bnc#466032)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 11 2004 adrian@suse.de
- buld as suer
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 rommel@suse.de
- using perl_vendorlib and perl_vendorarch instead of
  perl_archlib and perl_sitearch
* Tue Jul  1 2003 ro@suse.de
- use perl_process_packlist macro
* Mon Jun 23 2003 ro@suse.de
- added directories to filelist
* Thu Aug  8 2002 mls@suse.de
- use sitearch macro
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Wed Nov  8 2000 ro@suse.de
- added BUILD_ROOT_DIR
* Tue Nov  7 2000 grimmer@suse.de
- removed BuildRoot Path from .packlist using sed
* Mon Nov  6 2000 grimmer@suse.de
- Initial Package (splitted from package mysql, where it
  was part of subpackage mysqperl), Version 3.3
